# -*- coding: utf-8 -*-

keywords = {
    "abbrev",
    "abs",
    "abstime",
    "abstimeeq",
    "abstimege",
    "abstimegt",
    "abstimein",
    "abstimele",
    "abstimelt",
    "abstimene",
    "abstimeout",
    "abstimerecv",
    "abstimesend",
    "aclcontains",
    "aclinsert",
    "aclitemeq",
    "aclitemin",
    "aclitemout",
    "aclremove",
    "acos",
    "add_months",
    "aes128",
    "aes256",
    "age",
    "all",
    "alloc_rowid",
    "allowoverwrite",
    "alt_to_iso",
    "alt_to_koi8r",
    "alt_to_mic",
    "alt_to_win1251",
    "analyse",
    "analyze",
    "and",
    "any",
    "any_in",
    "any_out",
    "anyarray_in",
    "anyarray_out",
    "anyarray_recv",
    "anyarray_send",
    "anyelement_in",
    "anyelement_out",
    "area",
    "areajoinsel",
    "areasel",
    "array",
    "array_append",
    "array_cat",
    "array_coerce",
    "array_dims",
    "array_eq",
    "array_ge",
    "array_gt",
    "array_in",
    "array_le",
    "array_length_coerce",
    "array_lower",
    "array_lt",
    "array_ne",
    "array_out",
    "array_prepend",
    "array_recv",
    "array_send",
    "array_type_length_coerce",
    "array_upper",
    "as",
    "asc",
    "ascii",
    "ascii_to_mic",
    "asin",
    "atan",
    "atan2",
    "authorization",
    "avg",
    "az64",
    "backup",
    "between",
    "big5_to_euc_tw",
    "big5_to_mic",
    "binary",
    "bit",
    "bit_and",
    "bit_in",
    "bit_length",
    "bit_or",
    "bit_out",
    "bit_recv",
    "bit_send",
    "bitand",
    "bitcat",
    "bitcmp",
    "biteq",
    "bitge",
    "bitgt",
    "bitle",
    "bitlt",
    "bitne",
    "bitnot",
    "bitor",
    "bitxor",
    "blanksasnull",
    "bool",
    "bool_and",
    "bool_or",
    "booleq",
    "boolge",
    "boolgt",
    "boolin",
    "boolle",
    "boollt",
    "boolne",
    "boolout",
    "boolrecv",
    "boolsend",
    "both",
    "box",
    "box_above",
    "box_add",
    "box_below",
    "box_center",
    "box_contain",
    "box_contained",
    "box_distance",
    "box_div",
    "box_eq",
    "box_ge",
    "box_gt",
    "box_in",
    "box_intersect",
    "box_le",
    "box_lt",
    "box_mul",
    "box_out",
    "box_overlap",
    "box_recv",
    "box_same",
    "box_send",
    "box_sub",
    "bpchar",
    "bpchar_pattern_eq",
    "bpchar_pattern_ge",
    "bpchar_pattern_gt",
    "bpchar_pattern_le",
    "bpchar_pattern_lt",
    "bpchar_pattern_ne",
    "bpcharcmp",
    "bpchareq",
    "bpcharge",
    "bpchargt",
    "bpcharle",
    "bpcharlike",
    "bpcharlt",
    "bpcharne",
    "bpcharnlike",
    "bpcharout",
    "bpcharrecv",
    "bpcharregexeq",
    "bpcharregexne",
    "bpcharsend",
    "broadcast",
    "btabstimecmp",
    "btarraycmp",
    "btbeginscan",
    "btboolcmp",
    "btbpchar_pattern_cmp",
    "btbuild",
    "btbulkdelete",
    "btcharcmp",
    "btcostestimate",
    "btendscan",
    "btgettuple",
    "btinsert",
    "btint24cmp",
    "btint28cmp",
    "btint2cmp",
    "btint42cmp",
    "btint48cmp",
    "btint4cmp",
    "btint82cmp",
    "btint84cmp",
    "btint8cmp",
    "btmarkpos",
    "btname_pattern_cmp",
    "btnamecmp",
    "btoidcmp",
    "btoidvectorcmp",
    "btreltimecmp",
    "btrescan",
    "btrestrpos",
    "bttext_pattern_cmp",
    "bttextcmp",
    "bttintervalcmp",
    "btvacuumcleanup",
    "byteacat",
    "byteacmp",
    "byteaeq",
    "byteage",
    "byteagt",
    "byteain",
    "byteale",
    "bytealike",
    "bytealt",
    "byteane",
    "byteanlike",
    "byteaout",
    "bytearecv",
    "byteasend",
    "bytedict",
    "bzip2",
    "card_check",
    "case",
    "cash_cmp",
    "cash_div_int2",
    "cash_div_int4",
    "cash_eq",
    "cash_ge",
    "cash_gt",
    "cash_in",
    "cash_le",
    "cash_lt",
    "cash_mi",
    "cash_mul_int2",
    "cash_mul_int4",
    "cash_ne",
    "cash_out",
    "cash_pl",
    "cash_recv",
    "cash_send",
    "cash_words",
    "cashlarger",
    "cashsmaller",
    "cast",
    "cbrt",
    "ceil",
    "ceiling",
    "center",
    "char",
    "char_length",
    "character_length",
    "chareq",
    "charge",
    "chargt",
    "charle",
    "charlt",
    "charne",
    "charout",
    "charrecv",
    "charsend",
    "check",
    "checksum",
    "chr",
    "cideq",
    "cidin",
    "cidout",
    "cidr",
    "cidr_in",
    "cidr_out",
    "cidr_recv",
    "cidr_send",
    "cidrecv",
    "cidsend",
    "circle",
    "circle_above",
    "circle_add_pt",
    "circle_below",
    "circle_center",
    "circle_contain",
    "circle_contain_pt",
    "circle_contained",
    "circle_distance",
    "circle_div_pt",
    "circle_eq",
    "circle_ge",
    "circle_gt",
    "circle_in",
    "circle_le",
    "circle_lt",
    "circle_mul_pt",
    "circle_ne",
    "circle_out",
    "circle_overlap",
    "circle_recv",
    "circle_same",
    "circle_send",
    "circle_sub_pt",
    "close_lb",
    "close_ls",
    "close_lseg",
    "close_pb",
    "close_pl",
    "close_ps",
    "close_sb",
    "close_sl",
    "collate",
    "column",
    "concat",
    "constraint",
    "contains",
    "contjoinsel",
    "contsel",
    "convert",
    "convert_timezone",
    "convert_using",
    "cos",
    "cot",
    "count",
    "crc32",
    "create",
    "credentials",
    "cross",
    "cume_dist",
    "current_database",
    "current_date",
    "current_schema",
    "current_schemas",
    "current_setting",
    "current_time",
    "current_timestamp",
    "current_user",
    "current_user_id",
    "currtid",
    "currtid2",
    "currval",
    "cvtile_sf",
    "date",
    "date_add",
    "date_cmp",
    "date_cmp_timestamp",
    "date_cmp_timestamptz",
    "date_eq",
    "date_eq_timestamp",
    "date_eq_timestamptz",
    "date_ge",
    "date_ge_timestamp",
    "date_ge_timestamptz",
    "date_gt",
    "date_gt_timestamp",
    "date_gt_timestamptz",
    "date_in",
    "date_larger",
    "date_le",
    "date_le_timestamp",
    "date_le_timestamptz",
    "date_lt",
    "date_lt_timestamp",
    "date_lt_timestamptz",
    "date_mi",
    "date_mi_interval",
    "date_mii",
    "date_ne",
    "date_ne_timestamp",
    "date_ne_timestamptz",
    "date_out",
    "date_part",
    "date_part_year",
    "date_pl_interval",
    "date_pli",
    "date_recv",
    "date_send",
    "date_smaller",
    "date_trunc",
    "datetime_pl",
    "datetimetz_pl",
    "dcbrt",
    "default",
    "deferrable",
    "deflate",
    "defrag",
    "degrees",
    "delete_xid_column",
    "delta",
    "delta32k",
    "dense_rank",
    "desc",
    "dexp",
    "diagonal",
    "diameter",
    "disable",
    "dist_cpoly",
    "dist_lb",
    "dist_pb",
    "dist_pc",
    "dist_pl",
    "dist_ppath",
    "dist_ps",
    "dist_sb",
    "dist_sl",
    "distinct",
    "dlog1",
    "dlog10",
    "do",
    "dpow",
    "dround",
    "dsqrt",
    "dtrunc",
    "else",
    "emptyasnull",
    "enable",
    "encode",
    "encrypt     ",
    "encryption",
    "end",
    "eqjoinsel",
    "eqsel",
    "erf",
    "euc_cn_to_mic",
    "euc_jp_to_mic",
    "euc_jp_to_sjis",
    "euc_kr_to_mic",
    "euc_tw_to_big5",
    "euc_tw_to_mic",
    "every",
    "except",
    "exp",
    "explicit",
    "false",
    "for",
    "foreign",
    "freeze",
    "from",
    "full",
    "geometry_analyze",
    "geometry_in",
    "geometry_out",
    "geometry_recv",
    "geometry_send",
    "geometrytype",
    "get_bit",
    "get_byte",
    "getdatabaseencoding",
    "getdate",
    "gistbeginscan",
    "gistbuild",
    "gistbulkdelete",
    "gistcostestimate",
    "gistendscan",
    "gistgettuple",
    "gistinsert",
    "gistmarkpos",
    "gistrescan",
    "gistrestrpos",
    "globaldict256",
    "globaldict64k",
    "grant",
    "group",
    "gzip",
    "hash_aclitem",
    "hashbeginscan",
    "hashbpchar",
    "hashbuild",
    "hashbulkdelete",
    "hashchar",
    "hashcostestimate",
    "hashendscan",
    "hashgettuple",
    "hashinet",
    "hashinsert",
    "hashint2",
    "hashint2vector",
    "hashint4",
    "hashint8",
    "hashmacaddr",
    "hashmarkpos",
    "hashname",
    "hashoid",
    "hashoidvector",
    "hashrescan",
    "hashrestrpos",
    "hashtext",
    "hashvarlena",
    "haversine_distance_km",
    "haversine_distance_km2",
    "having",
    "height",
    "hll_cardinality_16",
    "hll_cardinality_32",
    "host",
    "hostmask",
    "iclikejoinsel",
    "iclikesel",
    "icnlikejoinsel",
    "icnlikesel",
    "icregexeqjoinsel",
    "icregexeqsel",
    "icregexnejoinsel",
    "icregexnesel",
    "identity",
    "ignore",
    "ilike",
    "in",
    "inet",
    "inet_client_addr",
    "inet_client_port",
    "inet_in",
    "inet_out",
    "inet_recv",
    "inet_send",
    "inet_server_addr",
    "inet_server_port",
    "initcap",
    "initially",
    "inner",
    "int2",
    "int24div",
    "int24eq",
    "int24ge",
    "int24gt",
    "int24le",
    "int24lt",
    "int24mi",
    "int24mod",
    "int24mul",
    "int24ne",
    "int24pl",
    "int28div",
    "int28eq",
    "int28ge",
    "int28gt",
    "int28le",
    "int28lt",
    "int28mi",
    "int28mul",
    "int28ne",
    "int28pl",
    "int2_accum",
    "int2_avg_accum",
    "int2_mul_cash",
    "int2_sum",
    "int2abs",
    "int2and",
    "int2div",
    "int2eq",
    "int2ge",
    "int2gt",
    "int2in",
    "int2larger",
    "int2le",
    "int2lt",
    "int2mi",
    "int2mod",
    "int2mul",
    "int2ne",
    "int2not",
    "int2or",
    "int2out",
    "int2pl",
    "int2recv",
    "int2send",
    "int2shl",
    "int2shr",
    "int2smaller",
    "int2um",
    "int2up",
    "int2vectoreq",
    "int2vectorout",
    "int2vectorrecv",
    "int2vectorsend",
    "int2xor",
    "int4",
    "int42div",
    "int42eq",
    "int42ge",
    "int42gt",
    "int42le",
    "int42lt",
    "int42mi",
    "int42mod",
    "int42mul",
    "int42ne",
    "int42pl",
    "int48div",
    "int48eq",
    "int48ge",
    "int48gt",
    "int48le",
    "int48lt",
    "int48mi",
    "int48mul",
    "int48ne",
    "int48pl",
    "int4_accum",
    "int4_avg_accum",
    "int4_mul_cash",
    "int4_sum",
    "int4abs",
    "int4and",
    "int4div",
    "int4eq",
    "int4ge",
    "int4gt",
    "int4in",
    "int4inc",
    "int4larger",
    "int4le",
    "int4lt",
    "int4mi",
    "int4mod",
    "int4mul",
    "int4ne",
    "int4not",
    "int4or",
    "int4out",
    "int4pl",
    "int4recv",
    "int4send",
    "int4shl",
    "int4shr",
    "int4smaller",
    "int4um",
    "int4up",
    "int4xor",
    "int8",
    "int82div",
    "int82eq",
    "int82ge",
    "int82gt",
    "int82le",
    "int82lt",
    "int82mi",
    "int82mul",
    "int82ne",
    "int82pl",
    "int84div",
    "int84eq",
    "int84ge",
    "int84gt",
    "int84le",
    "int84lt",
    "int84mi",
    "int84mul",
    "int84ne",
    "int84pl",
    "int8_accum",
    "int8_avg",
    "int8_avg_accum",
    "int8_pl_timestamp",
    "int8_pl_timestamptz",
    "int8_sum",
    "int8abs",
    "int8and",
    "int8div",
    "int8eq",
    "int8ge",
    "int8gt",
    "int8in",
    "int8inc",
    "int8larger",
    "int8le",
    "int8lt",
    "int8mi",
    "int8mod",
    "int8mul",
    "int8ne",
    "int8not",
    "int8or",
    "int8out",
    "int8pl",
    "int8recv",
    "int8send",
    "int8shl",
    "int8shr",
    "int8smaller",
    "int8um",
    "int8up",
    "int8xor",
    "integer_pl_date",
    "inter_lb",
    "inter_sb",
    "inter_sl",
    "internal_in",
    "internal_out",
    "intersect",
    "interval",
    "interval_accum",
    "interval_avg",
    "interval_cmp",
    "interval_div",
    "interval_eq",
    "interval_ge",
    "interval_gt",
    "interval_hash",
    "interval_in",
    "interval_larger",
    "interval_le",
    "interval_lt",
    "interval_mi",
    "interval_mul",
    "interval_ne",
    "interval_out",
    "interval_pl",
    "interval_pl_date",
    "interval_pl_time",
    "interval_pl_timestamp",
    "interval_pl_timestamptz",
    "interval_pl_timetz",
    "interval_recv",
    "interval_send",
    "interval_smaller",
    "interval_um",
    "intinterval",
    "into",
    "ip_aton",
    "ip_masking",
    "ip_ntoa",
    "is",
    "is_ssl_connection",
    "is_valid_json",
    "is_valid_json_array",
    "isclosed",
    "isnottrue",
    "isnull",
    "iso_to_alt",
    "iso_to_koi8r",
    "iso_to_mic",
    "iso_to_win1251",
    "isopen",
    "isparallel",
    "isperp",
    "istrue",
    "isvertical",
    "join",
    "json_array_length",
    "json_extract_array_element_text",
    "json_extract_path_text",
    "koi8r_to_alt",
    "koi8r_to_iso",
    "koi8r_to_mic",
    "koi8r_to_win1251",
    "lag",
    "language",
    "language_handler_in",
    "language_handler_out",
    "last_day",
    "last_value",
    "latin1_to_mic",
    "latin2_to_mic",
    "latin2_to_win1250",
    "latin3_to_mic",
    "latin4_to_mic",
    "lead",
    "leading",
    "left",
    "len",
    "length",
    "like",
    "like_escape",
    "likejoinsel",
    "likesel",
    "limit",
    "line",
    "line_distance",
    "line_eq",
    "line_in",
    "line_interpt",
    "line_intersect",
    "line_out",
    "line_parallel",
    "line_perp",
    "line_recv",
    "line_send",
    "line_vertical",
    "listagg",
    "listaggdistinct",
    "ln",
    "lo_close",
    "lo_creat",
    "lo_export",
    "lo_import",
    "lo_lseek",
    "lo_open",
    "lo_tell",
    "lo_unlink",
    "localtime",
    "localtimestamp",
    "log",
    "logistic",
    "loread",
    "lower",
    "lpad",
    "lseg",
    "lseg_center",
    "lseg_distance",
    "lseg_eq",
    "lseg_ge",
    "lseg_gt",
    "lseg_in",
    "lseg_interpt",
    "lseg_intersect",
    "lseg_le",
    "lseg_length",
    "lseg_lt",
    "lseg_ne",
    "lseg_out",
    "lseg_parallel",
    "lseg_perp",
    "lseg_recv",
    "lseg_send",
    "lseg_vertical",
    "lun",
    "luns",
    "lzo",
    "lzop",
    "macaddr",
    "macaddr_cmp",
    "macaddr_eq",
    "macaddr_ge",
    "macaddr_gt",
    "macaddr_in",
    "macaddr_le",
    "macaddr_lt",
    "macaddr_ne",
    "macaddr_out",
    "macaddr_recv",
    "macaddr_send",
    "makeaclitem",
    "masklen",
    "max",
    "md5",
    "median",
    "mic_to_alt",
    "mic_to_ascii",
    "mic_to_big5",
    "mic_to_euc_cn",
    "mic_to_euc_jp",
    "mic_to_euc_kr",
    "mic_to_euc_tw",
    "mic_to_iso",
    "mic_to_koi8r",
    "mic_to_latin1",
    "mic_to_latin2",
    "mic_to_latin3",
    "mic_to_latin4",
    "mic_to_sjis",
    "mic_to_win1250",
    "mic_to_win1251",
    "min",
    "minus",
    "mktinterval",
    "mod",
    "months_between",
    "mos_score",
    "mostly13",
    "mostly32",
    "mostly8",
    "mul_d_interval",
    "name",
    "name_pattern_eq",
    "name_pattern_ge",
    "name_pattern_gt",
    "name_pattern_le",
    "name_pattern_lt",
    "name_pattern_ne",
    "nameeq",
    "namege",
    "namegt",
    "nameiclike",
    "nameicnlike",
    "nameicregexeq",
    "nameicregexne",
    "namein",
    "namele",
    "namelike",
    "namelt",
    "namene",
    "namenlike",
    "nameout",
    "namerecv",
    "nameregexeq",
    "nameregexne",
    "namesend",
    "natural",
    "neqjoinsel",
    "neqsel",
    "netmask",
    "network",
    "network_cmp",
    "network_eq",
    "network_ge",
    "network_gt",
    "network_le",
    "network_lt",
    "network_ne",
    "network_sub",
    "network_subeq",
    "network_sup",
    "network_supeq",
    "new",
    "next_day",
    "nextval",
    "nlikejoinsel",
    "nlikesel",
    "node_num",
    "nonnullvalue",
    "not",
    "notlike",
    "notnull",
    "now",
    "npoints",
    "nth_value",
    "ntile",
    "null",
    "nulls",
    "nullvalue",
    "nvl2",
    "octet_length",
    "off",
    "offline",
    "offset",
    "oid",
    "oideq",
    "oidge",
    "oidgt",
    "oidin",
    "oidlarger",
    "oidle",
    "oidlt",
    "oidne",
    "oidout",
    "oidrecv",
    "oidsend",
    "oidsmaller",
    "oidvectoreq",
    "oidvectorge",
    "oidvectorgt",
    "oidvectorle",
    "oidvectorlt",
    "oidvectorne",
    "oidvectorout",
    "oidvectorrecv",
    "oidvectorsend",
    "oidvectortypes",
    "old",
    "on",
    "on_pb",
    "on_pl",
    "on_ppath",
    "on_ps",
    "on_sb",
    "on_sl",
    "only",
    "opaque_in",
    "opaque_out",
    "open",
    "or",
    "order",
    "outer",
    "overlaps",
    "parallel",
    "partition",
    "path",
    "path_add",
    "path_add_pt",
    "path_center",
    "path_contain_pt",
    "path_distance",
    "path_div_pt",
    "path_in",
    "path_inter",
    "path_length",
    "path_mul_pt",
    "path_n_eq",
    "path_n_ge",
    "path_n_gt",
    "path_n_le",
    "path_n_lt",
    "path_npoints",
    "path_out",
    "path_recv",
    "path_send",
    "path_sub_pt",
    "pclose",
    "percent",
    "percent_rank",
    "percentile_cont",
    "percentile_disc",
    "permissions",
    "pg_backend_pid",
    "pg_cancel_backend",
    "pg_char_to_encoding",
    "pg_client_encoding",
    "pg_conversion_is_visible",
    "pg_decode",
    "pg_encoding_to_char",
    "pg_get_cols",
    "pg_get_constraintdef",
    "pg_get_current_groups",
    "pg_get_expr",
    "pg_get_external_columns",
    "pg_get_external_tables",
    "pg_get_indexdef",
    "pg_get_late_binding_view_cols",
    "pg_get_ruledef",
    "pg_get_userbyid",
    "pg_get_viewdef",
    "pg_last_copy_count",
    "pg_last_copy_id",
    "pg_last_query_id",
    "pg_last_unload_count",
    "pg_last_unload_id",
    "pg_lock_status",
    "pg_opclass_is_visible",
    "pg_operator_is_visible",
    "pg_postmaster_start_time",
    "pg_show_all_settings",
    "pg_sleep",
    "pg_start_backup",
    "pg_stat_get_backend_activity",
    "pg_stat_get_backend_activity_start",
    "pg_stat_get_backend_dbid",
    "pg_stat_get_backend_idset",
    "pg_stat_get_backend_pid",
    "pg_stat_get_blocks_hit",
    "pg_stat_get_db_blocks_hit",
    "pg_stat_get_db_numbackends",
    "pg_stat_get_db_xact_commit",
    "pg_stat_get_db_xact_rollback",
    "pg_stat_get_numscans",
    "pg_stat_get_tuples_deleted",
    "pg_stat_get_tuples_inserted",
    "pg_stat_get_tuples_returned",
    "pg_stat_get_tuples_updated",
    "pg_stat_reset",
    "pg_stop_backup",
    "pg_table_is_visible",
    "pg_tablespace_databases",
    "pg_terminate_backend",
    "pg_timezone_abbrevs",
    "pg_timezone_names",
    "pg_type_is_visible",
    "pgdate_part",
    "pi",
    "placing",
    "plpython_call_handler",
    "plpython_compiler",
    "point",
    "point_above",
    "point_add",
    "point_below",
    "point_distance",
    "point_div",
    "point_eq",
    "point_in",
    "point_mul",
    "point_ne",
    "point_out",
    "point_recv",
    "point_send",
    "point_sub",
    "point_vert",
    "poly_center",
    "poly_contain",
    "poly_contain_pt",
    "poly_contained",
    "poly_distance",
    "poly_in",
    "poly_npoints",
    "poly_out",
    "poly_overlap",
    "poly_recv",
    "poly_same",
    "poly_send",
    "polygon",
    "popen",
    "position",
    "positionjoinsel",
    "positionsel",
    "pow",
    "power",
    "primary",
    "pt_contained_circle",
    "pt_contained_poly",
    "qsummary",
    "quote_ident",
    "quote_literal",
    "radians",
    "radius",
    "random",
    "rank",
    "rankx",
    "ratio_to_report",
    "raw",
    "readratio",
    "record_in",
    "record_out",
    "record_recv",
    "record_send",
    "recover",
    "references",
    "regclassin",
    "regclassout",
    "regclassrecv",
    "regclasssend",
    "regexeqjoinsel",
    "regexeqsel",
    "regexnejoinsel",
    "regexnesel",
    "regexp_count",
    "regexp_instr",
    "regexp_replace",
    "regexp_substr",
    "regoperatorout",
    "regoperatorrecv",
    "regoperatorsend",
    "regoperout",
    "regoperrecv",
    "regopersend",
    "regprocedurein",
    "regprocedureout",
    "regprocedurerecv",
    "regproceduresend",
    "regprocin",
    "regprocout",
    "regprocrecv",
    "regprocsend",
    "regtypein",
    "regtypeout",
    "regtyperecv",
    "regtypesend",
    "rejectlog",
    "reltime",
    "reltimeeq",
    "reltimege",
    "reltimegt",
    "reltimein",
    "reltimele",
    "reltimelt",
    "reltimene",
    "reltimeout",
    "reltimerecv",
    "reltimesend",
    "relu",
    "remaining_vacrows",
    "repeat",
    "replace",
    "replicate",
    "resort",
    "respect",
    "restore",
    "return_approx_percentile",
    "reverse",
    "right",
    "round",
    "row_number",
    "rownumber",
    "rpad",
    "rt_box_inter",
    "rt_box_size",
    "rt_box_union",
    "rt_poly_inter",
    "rt_poly_size",
    "rt_poly_union",
    "rtbeginscan",
    "rtbuild",
    "rtbulkdelete",
    "rtcostestimate",
    "rtendscan",
    "rtgettuple",
    "rtinsert",
    "rtmarkpos",
    "rtrescan",
    "rtrestrpos",
    "scalargtjoinsel",
    "scalargtsel",
    "scalarltjoinsel",
    "scalarltsel",
    "select",
    "session_user",
    "set_bit",
    "set_byte",
    "set_masklen",
    "setval",
    "sig_bucket_3g",
    "sig_bucket_lte",
    "sig_score_3g",
    "sig_score_lte",
    "sigmoid",
    "sign",
    "similar",
    "similar_escape",
    "sin",
    "sjis_to_euc_jp",
    "sjis_to_mic",
    "slice_num",
    "slope",
    "smgreq",
    "smgrne",
    "smgrout",
    "snapshot ",
    "some",
    "sort_avail_mem",
    "sortbytes",
    "split_part",
    "sqrt",
    "ssl_version",
    "st_asbinary",
    "st_asewkb",
    "st_asewkt",
    "st_astext",
    "st_azimuth",
    "st_contains",
    "st_dimension",
    "st_disjoint",
    "st_distance",
    "st_dwithin",
    "st_equals",
    "st_geometrytype",
    "st_intersects",
    "st_isclosed",
    "st_iscollection",
    "st_isempty",
    "st_makeline",
    "st_makepoint",
    "st_makepolygon",
    "st_npoints",
    "st_numpoints",
    "st_point",
    "st_polygon",
    "st_within",
    "st_x",
    "st_xmax",
    "st_xmin",
    "st_y",
    "st_ymax",
    "st_ymin",
    "stddev",
    "stddev_pop",
    "strpos",
    "strtol",
    "substr",
    "sum",
    "sysdate",
    "system",
    "table",
    "tablebytes",
    "tag",
    "tan",
    "tdes",
    "text",
    "text255",
    "text32k",
    "text_ge",
    "text_gt",
    "text_larger",
    "text_le",
    "text_lt",
    "text_pattern_eq",
    "text_pattern_ge",
    "text_pattern_gt",
    "text_pattern_le",
    "text_pattern_lt",
    "text_pattern_ne",
    "text_smaller",
    "textcat",
    "texteq",
    "texticlike",
    "texticnlike",
    "texticregexeq",
    "texticregexne",
    "textin",
    "textlen",
    "textlike",
    "textne",
    "textnlike",
    "textout",
    "textrecv",
    "textregexeq",
    "textregexne",
    "textsend",
    "then",
    "tideq",
    "tidin",
    "tidout",
    "tidrecv",
    "tidsend",
    "time",
    "time_cmp",
    "time_eq",
    "time_ge",
    "time_gt",
    "time_in",
    "time_larger",
    "time_le",
    "time_lt",
    "time_mi_interval",
    "time_mi_time",
    "time_ne",
    "time_out",
    "time_pl_interval",
    "time_recv",
    "time_send",
    "time_smaller",
    "timedate_pl",
    "timemi",
    "timenow",
    "timepl",
    "timestamp",
    "timestamp_cmp",
    "timestamp_cmp_date",
    "timestamp_cmp_timestamptz",
    "timestamp_eq",
    "timestamp_eq_date",
    "timestamp_eq_timestamptz",
    "timestamp_ge",
    "timestamp_ge_date",
    "timestamp_ge_timestamptz",
    "timestamp_gt",
    "timestamp_gt_date",
    "timestamp_gt_timestamptz",
    "timestamp_in",
    "timestamp_larger",
    "timestamp_le",
    "timestamp_le_date",
    "timestamp_le_timestamptz",
    "timestamp_lt",
    "timestamp_lt_date",
    "timestamp_lt_timestamptz",
    "timestamp_mi",
    "timestamp_mi_int8",
    "timestamp_mi_interval",
    "timestamp_ne",
    "timestamp_ne_date",
    "timestamp_ne_timestamptz",
    "timestamp_out",
    "timestamp_pl_int8",
    "timestamp_pl_interval",
    "timestamp_recv",
    "timestamp_send",
    "timestamp_smaller",
    "timestamptz",
    "timestamptz_cmp",
    "timestamptz_cmp_date",
    "timestamptz_cmp_timestamp",
    "timestamptz_eq",
    "timestamptz_eq_date",
    "timestamptz_eq_timestamp",
    "timestamptz_ge",
    "timestamptz_ge_date",
    "timestamptz_ge_timestamp",
    "timestamptz_gt",
    "timestamptz_gt_date",
    "timestamptz_gt_timestamp",
    "timestamptz_in",
    "timestamptz_larger",
    "timestamptz_le",
    "timestamptz_le_date",
    "timestamptz_le_timestamp",
    "timestamptz_lt",
    "timestamptz_lt_date",
    "timestamptz_lt_timestamp",
    "timestamptz_mi",
    "timestamptz_mi_int8",
    "timestamptz_mi_interval",
    "timestamptz_ne",
    "timestamptz_ne_date",
    "timestamptz_ne_timestamp",
    "timestamptz_out",
    "timestamptz_pl_int8",
    "timestamptz_pl_interval",
    "timestamptz_recv",
    "timestamptz_send",
    "timestamptz_smaller",
    "timetz",
    "timetz_cmp",
    "timetz_eq",
    "timetz_ge",
    "timetz_gt",
    "timetz_hash",
    "timetz_in",
    "timetz_larger",
    "timetz_le",
    "timetz_lt",
    "timetz_mi_interval",
    "timetz_ne",
    "timetz_out",
    "timetz_pl_interval",
    "timetz_recv",
    "timetz_send",
    "timetz_smaller",
    "timetzdate_pl",
    "timezone",
    "tinterval",
    "tintervalct",
    "tintervalend",
    "tintervaleq",
    "tintervalge",
    "tintervalgt",
    "tintervalin",
    "tintervalle",
    "tintervalleneq",
    "tintervallenge",
    "tintervallengt",
    "tintervallenle",
    "tintervallenlt",
    "tintervallenne",
    "tintervallt",
    "tintervalne",
    "tintervalout",
    "tintervalov",
    "tintervalrecv",
    "tintervalrel",
    "tintervalsame",
    "tintervalsend",
    "tintervalstart",
    "to",
    "to_ascii",
    "to_char",
    "to_date",
    "to_hex",
    "to_number",
    "to_timestamp",
    "tobpchar",
    "top",
    "total_num_deleted_vacrows",
    "total_num_deleted_vacrows_reclaimed",
    "trailing",
    "translate",
    "true",
    "trunc",
    "truncatecolumns",
    "union",
    "unique",
    "unknownin",
    "unknownout",
    "unknownrecv",
    "unknownsend",
    "upper",
    "user",
    "using",
    "vacstate_endrow",
    "vacstate_last_inserted_row",
    "var_pop",
    "varbit",
    "varbit_in",
    "varbit_out",
    "varbit_recv",
    "varbit_send",
    "varbitcmp",
    "varbiteq",
    "varbitge",
    "varbitgt",
    "varbitle",
    "varbitlt",
    "varbitne",
    "varchar",
    "varcharout",
    "varcharrecv",
    "varcharsend",
    "verbose",
    "version",
    "void_in",
    "void_out",
    "wallet",
    "when",
    "where",
    "width",
    "width_bucket",
    "win1250_to_latin2",
    "win1250_to_mic",
    "win1250_to_utf",
    "win1251_to_alt",
    "win1251_to_iso",
    "win1251_to_koi8r",
    "win1251_to_mic",
    "win1256_to_utf",
    "win874_to_utf",
    "with",
    "without",
    "xideq",
    "xideqint4",
    "xidin",
    "xidout",
    "xidrecv",
    "xidsend",
}
